@@ -2,12 +2,12 @@
 from django.contrib import admin
 from django.contrib.admin.options import ModelAdmin
 
-from models import DynamicTemplate
+from models import DynamicTemplate, StaticFile
 
-class DynamicTemplateAdmin(ModelAdmin):
+class AdminDynamicTemplate(ModelAdmin):
     list_display = ('title','slug','group',)
     search_fields = ('title','content','group')
 
-
-admin.site.register(DynamicTemplate, DynamicTemplateAdmin)
+admin.site.register(DynamicTemplate, AdminDynamicTemplate)
+admin.site.register(StaticFile)
 
